@@ -11,7 +11,13 @@ sub call {
 
     $self->response_cb($self->app->($env), sub {
         my $res = shift;
-        $res->[2] = [];
+        if ($res->[2]) {
+            $res->[2] = [];
+        } else {
+            return sub {
+                return defined $_[0] ? '': undef;
+            };
+        }
     });
 }
 
