@@ -2,7 +2,7 @@ package Plack::Request;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '1.0002';
+our $VERSION = '1.0003';
 $VERSION = eval $VERSION;
 
 use HTTP::Headers;
@@ -187,7 +187,7 @@ sub uri {
     # spec goes and we can't do anything about it. See PSGI::FAQ for details.
 
     # See RFC 3986 before modifying.
-    my $path_escape_class = q{^/;:@&=A-Za-z0-9$_.+!*'(),-};
+    my $path_escape_class = q{^/;:@&=A-Za-z0-9\$_.+!*'(),-};
 
     my $path = URI::Escape::uri_escape($self->env->{PATH_INFO} || '', $path_escape_class);
     $path .= '?' . $self->env->{QUERY_STRING}
